% SimCOVID Version 1.0, March 2020
% Author: Ismael Abdulrahman
% This program was made for the paper: "SimCOVID: An Open-Source Simulation Program for the COVID-19 Outbreak"
% The data was taken from: https://www.ecdc.europa.eu/en/geographical-distribution-2019-ncov-cases
% Case: Italy Outbreak
% Note: Please install the latest version of MATLAB\Simulink (R2019b or newer) 
% as the Simulink programs were built using version R2019break
%==========================================================================
clear all; clc;
P   = 60*10^6; % Population, Susceptible, N, S0
I0  = 1;       % Initial value for "Infectious"
R0  = 0;       % Initial value for "Removed"
st1 = 40;      % starting time 1 (step time)
st2 = 52;      % starting time 2 (step time)
%==========================================================================
%%%%% These are the initial values were used for optimization
% beta = 1.630633087430959;
% gamma1 =  0.011896752615454; 
% gamma2 = 0.004770759526414;
% gamma3 = 0.148957254923337;
% zeta1 = -1.903064649835499;
% zeta2 = -2.448422118867243;
% zeta3 = -2.646702454527070;
%==========================================================================
%%%%% These are the final values from the optimization obtained by Simulink
beta    = 1.527352345556211;
gamma1  =  0.012685137768588; 
gamma2  = 0.004775769312226;
gamma3  = 0.147606696122850;
zeta1   = -2.034955823693075;
zeta2   = -2.619079070429671;
zeta3   = -2.556469073666612;
I1 = xlsread('COVID-19-geographic-disbtribution-worldwide-2020-04-07','Italy','E:E');
I  = flip(I1);  I=I(32:end); %  The first 31 elements are zeros
C  =cumsum(I);               % Cumulative sum of I   
t  = 1:length(C);          
xy = [t' C];
xy0 = [t' I];
%=============================Plotting=====================================
figure (1)
t_length=180;
simOut = sim('Program_1_Italy_SIR',t_length);
plot(simOut.C, 'linewidth',2)
grid on;set(gca,'fontsize',16);
xlabel('Time (day)','FontSize',16,'FontWeight','bold');
xlim([0 t_length])
ylabel('Cumulative Infectious (person)','FontSize',16,'FontWeight','bold');
hold on
plot(C, 'linewidth',2)
legend({'simulated infectious','reported cases'}, 'FontSize',12);
dateaxis('x', 6, '31-Jan-2020')

figure (2)
plot(simOut.I, 'linewidth',2)
grid on;set(gca,'fontsize',16);
xlabel('Time (day)','FontSize',16,'FontWeight','bold');
xlim([0 t_length])
ylabel('Cumulative Infectious (person)','FontSize',16,'FontWeight','bold');
hold on
plot(I, 'linewidth',2)
legend({'simulated infectious','reported cases'}, 'FontSize',12);
dateaxis('x', 6, '31-Jan-2020')
%==========================================================================
